@@ -1,12 +1,9 @@
-import pytest
 import time
 
-from birdbrain_constant import BirdbrainConstant
-from birdbrain_exception import BirdbrainException
-from birdbrain_microbit import BirdbrainMicrobit
 from birdbrain_hummingbird import BirdbrainHummingbird
 from birdbrain_hummingbird_output import BirdbrainHummingbirdOutput
 
+
 def test_led():
     hummingbird = BirdbrainHummingbird("A")
 
@@ -15,6 +12,7 @@ def test_led():
 
     BirdbrainHummingbirdOutput.led(hummingbird.device, 1, "0")
 
+
 def test_tri_led():
     hummingbird = BirdbrainHummingbird("A")
 
@@ -23,6 +21,7 @@ def test_tri_led():
 
     BirdbrainHummingbirdOutput.tri_led(hummingbird.device, 1, 0, 0, 0)
 
+
 def test_position_servo():
     hummingbird = BirdbrainHummingbird("A")
 
@@ -32,6 +31,7 @@ def test_position_servo():
     BirdbrainHummingbirdOutput.position_servo(hummingbird.device, 1, 160)
     time.sleep(0.15)
 
+
 def test_rotation_servo():
     hummingbird = BirdbrainHummingbird("A")
 
